/* -*- mode: c++; c-basic-offset: 3; -*- */
#include "woutput.hh"

#include <sstream>

using namespace wpipe;
using namespace std;

//======================================  Output type constructor
wouttype::wouttype(void) {
}

//======================================  Output type constructor
wouttype::wouttype(const str_vect& channels, const std::string& time, 
		   const std::string& dir, const std::string& fmt, 
		   const std::string& type)
   : channelNames(channels)
{
   size_t N = channels.size();
   _paths.resize(N);

   //------------------------------------  global file (e.g. livetime.txt)
   if (N == 1 && channels[0] == "*") {
      ostringstream oss;
      oss << dir  << "/" << type << "-" << time << "." << fmt;
      _paths[0] = oss.str();
   }

   //------------------------------------  Trigger files...
   else {
      for (size_t i=0; i<N; i++) {
	 ostringstream oss;
	 oss << dir  << "/" << channels[i].substr(0, 2) << "-OMEGA_TRIGGERS_"
	     << type << "-" << time << "." << fmt;
	 _paths[i] = oss.str();
      }
   }
}

//======================================  Find channel number
size_t 
wouttype::find(const std::string& chan) const {
   size_t N = channelNames.size();
   if (N == 1 && channelNames[0] == "*") return 0;

   for (size_t i=0; i<N; i++) {
      if (chan == channelNames[i]) return i;
   }
   return N;
}

//======================================  wOutput constructor
woutput::woutput(const str_vect& chans, const string& time, const string& dir, 
		 const string& fmt, const str_vect& otyp) {
   if (otyp.empty()) {
      addtype(chans, time, dir, fmt, "DOWNSELECT");
      addtype(chans, time, dir, fmt, "CLUSTER");
      addtype(chans, time, dir, fmt, "COINCIDE");
   }

   else {
      size_t N=otyp.size();
      //out_map.resize(N);
      for (size_t i=0; i<N; i++) {
	 addtype(chans, time, dir, fmt, otyp[i]);
      }
   }
}

//======================================  wOutput constructor
void 
woutput::addtype(const str_vect& chans, const string& time, const string& dir, 
		 const string& fmt, const string& type) {
   out_map.insert(omap_value(type, wouttype(chans, time, dir, fmt, type)));
}
